==> live_chat_sdk-0.0.4.tar.gz: lib/suru_rock.dart <==



import 'package:firebase_core/firebase_core.dart';
import 'package:firebase_messaging/firebase_messaging.dart';
import 'package:flutter/material.dart';
import 'package:live_chat_sdk/interface.dart';
import 'package:notification_permissions/notification_permissions.dart';

Future<void> main() async {
  WidgetsFlutterBinding.ensureInitialized();
  await Firebase.initializeApp();
  var request = await FirebaseMessaging.instance.requestPermission();
  String? token = await FirebaseMessaging.instance.getToken();
  print('surender kumar token package token $token');
  runApp(const MyApp());
}

class MyApp extends StatelessWidget {
  const MyApp({Key? key}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      theme: ThemeData(
        scaffoldBackgroundColor: const Color(0xffDDD6D1),
        fontFamily: "Boucherie Cursive",
      ),
      debugShowCheckedModeBanner: false,
      home:  homepage(),
    );
  }
}



class homepage extends StatefulWidget {
  @override
  _homepageState createState() => _homepageState();
}

class _homepageState extends State<homepage> {
  @override
  void initState() {
    super.initState();
    requestNotification();
  }

  requestNotification(){
    Future<PermissionStatus> permissionStatus =
    NotificationPermissions.getNotificationPermissionStatus();
    final firebaseMessaging = Rj31();
    firebaseMessaging.setPostString();
  }



  @override
  Widget build(BuildContext context) {
    return Container();
  }
}

==> live_chat_sdk-0.0.5.tar.gz: lib/suru_rock.dart <==
import 'package:firebase_core/firebase_core.dart';
import 'package:firebase_messaging/firebase_messaging.dart';
import 'package:flutter/material.dart';
import 'package:live_chat_sdk/interface.dart';
import 'package:live_chat_sdk/provider/notify_data.dart';
import 'package:notification_permissions/notification_permissions.dart';
import 'package:provider/provider.dart';

Future<void> main() async
{
  WidgetsFlutterBinding.ensureInitialized();
  await Firebase.initializeApp();
  var request = await FirebaseMessaging.instance.requestPermission();
  String? token = await FirebaseMessaging.instance.getToken();
  print('surender kumar token package token $token');
  runApp(const MyApp());
}

class MyApp extends StatelessWidget {
  const MyApp({Key? key}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return MultiProvider(
        providers: [
        ChangeNotifierProvider(create: (_) => NotifyData()),
    ],
    child: MaterialApp(
      theme: ThemeData(
        scaffoldBackgroundColor: const Color(0xffDDD6D1),
        fontFamily: "Boucherie Cursive",
      ),
      debugShowCheckedModeBanner: false,
      home:  homepage(),
      )
    );
  }
}



class homepage extends StatefulWidget {
  @override
  _homepageState createState() => _homepageState();
}

class _homepageState extends State<homepage> {
  @override
  void initState() {
    super.initState();
    requestNotification();
  }

  requestNotification()
  {
    Future<PermissionStatus> permissionStatus = NotificationPermissions.getNotificationPermissionStatus();
    final firebaseMessaging = Rj31();
    firebaseMessaging.setPostString(context);
  }



  @override
  Widget build(BuildContext context) {
    return Container();
  }
}
